@@ -7,11 +7,10 @@ from typing import Any, Optional
 
 import requests
 
-from airbyte_cdk.sources.declarative.incremental.declarative_cursor import DeclarativeCursor
 from airbyte_cdk.sources.declarative.requesters.paginators.strategies.pagination_strategy import (
     PaginationStrategy,
 )
-from airbyte_cdk.sources.streams.concurrent.cursor import ConcurrentCursor
+from airbyte_cdk.sources.streams.concurrent.cursor import Cursor
 from airbyte_cdk.sources.types import Record
 
 
@@ -29,8 +28,7 @@ class PaginationStopCondition(ABC):
 class CursorStopCondition(PaginationStopCondition):
     def __init__(
         self,
-        cursor: DeclarativeCursor
-        | ConcurrentCursor,  # migrate to use both old and concurrent versions
+        cursor: Cursor,
     ):
         self._cursor = cursor
 
